@@ -441,9 +441,9 @@ public:
 
   void draw_link(pdf::link::Link *link, const std::string &border_color)
   {
-    sexpr::GCLock gc_lock;
     if (!config.hyperlinks.extract)
       return;
+    sexpr::Guard guard;
     double x1, y1, x2, y2;
     pdf::link::Action *link_action = link->getAction();
     if (link_action == nullptr)
@@ -767,7 +767,6 @@ static void add_meta_date(const char *key, const pdf::Timestamp &value, std::ost
 
 static void pdf_metadata_to_djvu_metadata(pdf::Metadata &metadata, std::ostream &stream)
 {
-  sexpr::GCLock gc_lock;
   metadata.iterate<std::ostream>(add_meta_string, add_meta_date, stream);
 }
 
@@ -1616,6 +1615,7 @@ static int xmain(int argc, char * const argv[])
       }
     }
     { /* Extract annotations (hyperlinks); save it into the sed file: */
+      sexpr::Guard guard;
       debug(3) << _("extracting annotations") << std::endl;
       const std::vector<sexpr::Ref> &annotations = outm->get_annotations();
       sed_file << "select 1" << std::endl << "set-ant" << std::endl;
@@ -1679,7 +1679,6 @@ static int xmain(int argc, char * const argv[])
       debug(0)--;
       if (xmp_bytes.length())
       {
-        sexpr::GCLock gc_lock;
         static sexpr::Ref xmp_symbol = sexpr::symbol("xmp");
         sexpr::Ref xmp = sexpr::nil;
         xmp = sexpr::cons(sexpr::string(xmp_bytes), xmp);
